pub struct PushSuperblock {
pub superblock: Pubkey,
pub signer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for PushSuperblock.
Fields
superblock: Pubkeysigner: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for PushSuperblockwhere
Pubkey: BorshSerialize,
impl BorshSerialize for PushSuperblockwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for PushSuperblock
impl ToAccountMetas for PushSuperblock
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for PushSuperblock
impl RefUnwindSafe for PushSuperblock
impl Send for PushSuperblock
impl Sync for PushSuperblock
impl Unpin for PushSuperblock
impl UnwindSafe for PushSuperblock